<?php
/**
 * Elementor themify icon control.
 *
 */
class Control_Themify_Icon extends \Elementor\Base_Data_Control {

	/**
	 * Get icon control type.
	 *
	 * Retrieve the control type, in this case `icon`.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Control type.
	 */
	public function get_type() {
		return 'themifyicon';
	}
	
	public function enqueue() {
		wp_register_style( 'themify-icons', get_theme_file_uri( '/assets/css/themify-icons.css' ), false, '1.0' );
		wp_enqueue_style( 'themify-icons' );
	}

	/**
	 * Get icons.
	 *
	 * Retrieve all the available icons.
	 *
	 * @since 1.0.0
	 * @access public
	 * @static
	 *
	 * @return array Available icons.
	 */
	public static function get_icons() {
		
		$menu_ico = miion_menuTiIcons();
		$themify_array = array();
		foreach( $menu_ico as $icons ){
			$cont = str_replace("\\","&#x",$icons[2]).';'; // &#x\f000
			$ico_class = str_replace("ti-","",$icons[1]); 
			$themify_array[$icons[1]] = $ico_class .' '. $cont;
		}
	
		return $themify_array;
	}

	/**
	 * Get icons control default settings.
	 *
	 * Retrieve the default settings of the icons control. Used to return the default
	 * settings while initializing the icons control.
	 *
	 * @since 1.0.0
	 * @access protected
	 *
	 * @return array Control default settings.
	 */
	protected function get_default_settings() {
		return [
			'options' => self::get_icons(),
			'include' => '',
			'exclude' => '',
		];
	}

	/**
	 * Render icons control output in the editor.
	 *
	 * Used to generate the control HTML in the editor using Underscore JS
	 * template. The variables for the class are available using `data` JS
	 * object.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function content_template() {
		$control_uid = $this->get_control_uid();

		?>
		<div class="elementor-control-field">
			<label for="<?php echo $control_uid; ?>" class="elementor-control-title">{{{ data.label }}}</label>
			<div class="elementor-control-input-wrapper">
				<select id="<?php echo $control_uid; ?>" class="elementor-control-ti-icon" data-setting="{{ data.name }}" data-placeholder="<?php echo __( 'Select Icon', 'miion-core' ); ?>" style="font-family: 'themify';">
					<option value=""><?php echo __( 'Select Icon', 'miion-core' ); ?></option>
					<# _.each( data.options, function( option_title, option_value ) { #>
					<option value="{{ option_value }}">{{{ option_title }}}</option>
					<# } ); #>
				</select>
			</div>
		</div>
		<# if ( data.description ) { #>
		<div class="elementor-control-field-description">{{ data.description }}</div>
		<# } #>
		<?php
	}
}
